clear all
close all

addpath('Data')

plotsettings

[num,txt,both] = xlsread('time-series-19-covid-combined_csv.xlsx'); %only data till 23 Mar
keycon = csvread('key-countries-pivoted_March30.csv',1,1); % data till 30 Mar 
[numus,txtus,~] = xlsread('us-states.xlsx');

US_30Mar = keycon(:,2);
IN_30Mar = keycon(:,9);
ndays2=size(US_30Mar,1);
date_30Mar = zeros(size(US_30Mar));

%%
ndays = 61;

date=datenum(num(1:61,1));

date_30Mar(1:ndays)=date
for i=1:8
    ii=ndays+i
date_30Mar(ii)=date(end)+i
end

cases = reshape(num(:,6),[61 487]) ;

for i=1:487
    ctr = 2+(i-1)*61;
    cntry{i} = txt{ctr,2}; 
end

for i=2:size(txt,1)
    city{i-1} = txt{i,3}; 
end
%%
% data till 23 March for exponential model

index = find(strcmp(cntry, 'India'));
IN = cases(:,index);
figure
i=index;
stem(date,cases(:,i),'-o','linewidth',2)

datetick('x','ddmmm','keeplimits','keepticks')
if(isempty(city{i*61}))
    fname = cntry{i};
else
fname = strcat(city{i*61}, {', '}, cntry{i})
end

title(fname)
xlabel('date')
ylabel('Confirmed cases')

%%
%% plot comparison with different countries / states in the US
figure
hold on
index = find(strcmp(txtus, 'New York'));
plot(numus(index,4),'s--k','linewidth',2)
l2 = txtus(index(1));

index = find(strcmp(txtus, 'New Jersey'));
plot(numus(index,4),'p-m','linewidth',2)
l3 = txtus(index(1));

index = find(strcmp(txtus, 'California'));
numus(index,4)
plot(numus(index,4),'*-r','linewidth',2)
l4 = txtus(index(1));

index = find(strcmp(txtus, 'Washington'));
numus(index,4)

plot(numus(index,4),'d--c','linewidth',2)
l5 = txtus(index(1));

plot(keycon(9:end,9),'v--k','linewidth',2);
l6 = 'India';

plot(keycon(10:end,4),'^-.g','linewidth',2);
l7 = 'Italy';

plot(keycon(3:end,5),'<-m','linewidth',2);
l8 = 'France';

legend([l2,l3,l4,l5,l6,l7,l8],'location','Best')

%set(gca, 'YScale', 'log')
ylim([1 1000])

grid on
xlabel('Days')
ylabel('Confirmed cases')

xtickangle(45)


%% make an exponential fit
daystot = linspace(1,61,61)';
i1=50; % 11 March is the first day
days = daystot(1:end-i1+1);
data = cases(i1:end,i);
[f,gof,out]=fit(days,data,'exp1')

forig = f(days);


%% predict
is=days(end);

daysnew = linspace(is+1,is+14,14);

%        a =    39.64; %7.15; %0.03192 ; % (0.001122, 0.003191)
%        b =    0.1887; %0.1801; %  0.1803 ; % (0.3093, 0.3282)
%        forig = a*exp(b*days)
%fnew = a*exp(b*daysnew)
     

fnew = f(daysnew)

%%
funrange = linspace(1,daysnew(end),daysnew(end))
frange = f(funrange)

off=date(1)+i1-2;
figure
plot(date-1,IN,'or')

hold on
plot(daysnew+off,fnew,'*')
index = find(strcmp(txtus, 'Washington'))
plot(numus(index,1)+7,numus(index,4),'d--m','linewidth',2)
l5 = txtus(index(1));

plot(funrange+off,frange,'--k')
plot(date_30Mar-1,IN_30Mar,'or')

legend('Confirmed','Predicted(23Mar)','Washington (shifted by 9 days)','Location','Best');
xlabel('Date')
ylabel('Covid-19 Cases in India')
grid on
datetick('x','ddmmm','keeplimits','keepticks')
txt = {'Fit:','y = 39.64 exp(0.1887x)'};
text(43890,4000,txt,'FontSize',20)
xtickangle(45)

%% long range
daysnew2 = linspace(is+1,is+60,60);

figure
plot(date-1,IN,'or')

hold on
plot(daysnew2+off,f(daysnew2),'*')
plot(funrange+off,frange,'--k')
plot(date_30Mar-1,IN_30Mar,'or')

index = find(strcmp(txtus, 'Washington'))
plot(numus(index,1)+7,numus(index,4),'d--c','linewidth',2)
l5 = txtus(index(1));

legend('Confirmed','Predicted(23Mar)','Location','Best');
xlabel('Date')
ylabel('Covid-19 Cases in India')
xlim([43910 43950])
grid on
datetick('x','ddmmm','keeplimits','keepticks')
txt = {'Fit:','y = 39.64 exp(0.1887x)'};
text(43930,200000,txt,'FontSize',20)
xtickangle(45)

%% long range - effects of lockdown 
daysnew2 = linspace(is+1,is+30,30)

daysnew3 = linspace(is+16,is+50,35)
forig = f(daysnew3);
dorig = diff(forig);
flockdown70(1) = forig(1);
flockdown50(1) = forig(1);
flockdown30(1) = forig(1);
flockdown90(1) = forig(1);

for i=1:length(forig)-1
    flockdown90(i+1)=  flockdown90(i) + dorig(i);
end

for i=1:length(forig)-1
    flockdown70(i+1)=  flockdown70(i) + 0.7*dorig(i);
end

for i=1:length(forig)-1
    flockdown50(i+1)=  flockdown50(i) + 0.5*dorig(i);
end

for i=1:length(forig)-1
    flockdown30(i+1)=  flockdown30(i) + 0.3*dorig(i);
end


figure
plot(date-1,IN,'or')

hold on
plot(daysnew2+off,f(daysnew2),'*')
plot(daysnew3+off,flockdown70,'-sr')
plot(daysnew3+off,flockdown50,'-vb')
plot(daysnew3+off,flockdown30,'-dk')

plot(funrange+off,frange,'--k')
plot(date_30Mar-1,IN_30Mar,'or')

legend('Confirmed','Predicted(23Mar - No Lockdown)','Predicted (Lockdown Effects - 30\%)','Predicted (Lockdown Effects - 50\%)','Predicted (Lockdown Effects - 70\%)','Location','Best');
xlabel('Date')
ylabel('Covid-19 Cases in India')
xlim([43910 43940])
grid on
datetick('x','ddmmm','keeplimits','keepticks')
txt = {'Fit:','y = 39.64 exp(0.1887x)'};
text(43930,200000,txt,'FontSize',20)
xtickangle(45)

